View source: R/translate_functions.R
I've made some opinionated recoding of module 1,2,&3's coding to bring them in line with 4/5
1 | decode_education(data, var_name, module_var)
|
data |
a data frame from CSES |
var_name |
the name of the column with gender encoding |
module_var |
name of column with module information |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.